#ifndef __GENOME_MIXER_CHROMOSOME__
#define __GENOME_MIXER_CHROMOSOME__

#define CHR_DEBUG_MESSAGES	false

#include "GeneRange.h"
#include <vector>
#include <assert.h>
#include <iostream>
#include <string>

using namespace std;

class Chromosome {
private:
    int thisChrNum;
    std::vector<GeneRange*> genes; // vector of GeneRange pointers
    int  genOfRecombination;
    
    static std::vector<string> chrNames;
    static std::vector<float> chrMBaseLength;
    static std::vector<float> chr_cM_Length;
    static int myNumChrWithXY; // number of chromosomes from 1 to X, but not including Y
    static int myXChrIndex; // the index of the X chromosome (since it is handled differently)
    static int myYChrIndex; // the index of the Y chromosome (since it is handled differently)

public:
    Chromosome::Chromosome();			// Constructor
    Chromosome::Chromosome(int theNum);		// Constructor

    // Class-wide static functions
    static void   Chromosome::printClassData(void);
    static string Chromosome::chrNameFromIndex(int chrNum);
    static float  Chromosome::lengthMBASEfromIndex(int chrNum);
    static long   Chromosome::lengthBasesFromIndex(int chrNum);
    static float  Chromosome::length_cM_fromIndex(int chrNum);
    
    static float  Chromosome::allChrTotal_cM(void);
    static long   Chromosome::allChrTotalBases(void);

    static void   Chromosome::setNumberOfChromosomes(int numChr);
    static void   Chromosome::clearAllChrData(void);
    static void   Chromosome::addChrData(string chrName, float chr_MB, float chr_cM);
    static int    Chromosome::numChr(); // <-- class variable accessor function
    static int    Chromosome::xChrIndex(); // <-- class variable accessor function
    static int    Chromosome::yChrIndex(); // <-- class variable accessor function
    // End of static functions
    
    void       Chromosome::addCopyOfGR(GeneRange *newGeneRange);
    void       Chromosome::addGR(long start, long end, int setTo);
    void       Chromosome::addPurebredGR(int setTo);
    GeneRange* Chromosome::getGRfromActual(long findActual);
    GeneRange* Chromosome::getGRfromIndex(long thisIndex);
    long       Chromosome::getIndexFromActual(long thisGeneNum);
    void       Chromosome::printGeneRanges(void);
    
    void       Chromosome::setNum(int newNum);
    
    bool   Chromosome::isFemSexChr();
    bool   Chromosome::isMaleSexChr();

    int     Chromosome::numberOfChr(void);
    string  Chromosome::name(void);
    int     Chromosome::num(void);
    float   Chromosome::lengthMBASE(void);
    long    Chromosome::lengthBases(void);
    float   Chromosome::length_cM(void);
    unsigned long    Chromosome::numGeneRanges(void);
        
};  // <-- remember the semicolon at the end of the class definition!


#endif
